==> jc-1.4.0.tar.gz: soot/toolkits/scalar/SimpleLocalUses.h <==
// public class soot.toolkits.scalar.SimpleLocalUses

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 879bfc0cba9d27a8 soot_toolkits_scalar_SimpleLocalUses

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_toolkits_scalar_SimpleLocalUses_H_
#define _JC_soot_toolkits_scalar_SimpleLocalUses_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;
struct _jc_soot_Unit$object;
struct _jc_soot_toolkits_graph_UnitGraph$object;
struct _jc_soot_toolkits_scalar_LocalDefs$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_SimpleLocalUses$sub_refs	_jc_soot_toolkits_scalar_SimpleLocalUses$sub_refs;
typedef struct _jc_soot_toolkits_scalar_SimpleLocalUses$sub_nonrefs	_jc_soot_toolkits_scalar_SimpleLocalUses$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_SimpleLocalUses$refs	_jc_soot_toolkits_scalar_SimpleLocalUses$refs;
typedef struct _jc_soot_toolkits_scalar_SimpleLocalUses$nonrefs	_jc_soot_toolkits_scalar_SimpleLocalUses$nonrefs;
typedef struct _jc_soot_toolkits_scalar_SimpleLocalUses$object	_jc_soot_toolkits_scalar_SimpleLocalUses$object;

typedef const struct _jc_soot_toolkits_scalar_SimpleLocalUses$vmethods	_jc_soot_toolkits_scalar_SimpleLocalUses$vmethods;
typedef const struct _jc_soot_toolkits_scalar_SimpleLocalUses$vtable	_jc_soot_toolkits_scalar_SimpleLocalUses$vtable;
typedef const struct _jc_soot_toolkits_scalar_SimpleLocalUses$vtype	_jc_soot_toolkits_scalar_SimpleLocalUses$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_SimpleLocalUses$method$_init$f9b52af7f539e9ce(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLocalUses$object *, struct _jc_soot_Body$object *, struct _jc_object *);
extern void _jc_soot_toolkits_scalar_SimpleLocalUses$method$_init$b799bdb7699f2961(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLocalUses$object *, struct _jc_soot_toolkits_graph_UnitGraph$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_soot_toolkits_scalar_SimpleLocalUses$method$getUsesOf$de01c1d1f6666f7b(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLocalUses$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_scalar_SimpleLocalUses$method_info$getUsesOf$de01c1d1f6666f7b;

// Virtual methods structure
struct _jc_soot_toolkits_scalar_SimpleLocalUses$vmethods {
	struct _jc_object	*(*getUsesOf$de01c1d1f6666f7b)(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLocalUses$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_toolkits_scalar_SimpleLocalUses$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_SimpleLocalUses$vmethods	soot_toolkits_scalar_SimpleLocalUses;
};

// Vtype
struct _jc_soot_toolkits_scalar_SimpleLocalUses$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_SimpleLocalUses$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_SimpleLocalUses$sub_refs {
	struct _jc_object	*unitToUses;
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_SimpleLocalUses$refs {
    _jc_soot_toolkits_scalar_SimpleLocalUses$sub_refs	soot_toolkits_scalar_SimpleLocalUses;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_SimpleLocalUses$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_SimpleLocalUses$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_SimpleLocalUses$sub_nonrefs	soot_toolkits_scalar_SimpleLocalUses;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_SimpleLocalUses$object {
	_jc_soot_toolkits_scalar_SimpleLocalUses$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_SimpleLocalUses$vtype	*vtype;
	_jc_soot_toolkits_scalar_SimpleLocalUses$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_SimpleLocalUses$vtype _jc_soot_toolkits_scalar_SimpleLocalUses$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_SimpleLocalUses, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_SimpleLocalUses$class_object;

#endif	/* _JC_soot_toolkits_scalar_SimpleLocalUses_H_ */

==> jc-1.4.6.tar.gz: soot/toolkits/scalar/SimpleLocalUses.h <==
// public class soot.toolkits.scalar.SimpleLocalUses

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 879bfc0cba9d27a8 soot_toolkits_scalar_SimpleLocalUses

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_toolkits_scalar_SimpleLocalUses_H_
#define _JC_soot_toolkits_scalar_SimpleLocalUses_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;
struct _jc_soot_Unit$object;
struct _jc_soot_toolkits_graph_UnitGraph$object;
struct _jc_soot_toolkits_scalar_LocalDefs$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_SimpleLocalUses$sub_refs	_jc_soot_toolkits_scalar_SimpleLocalUses$sub_refs;
typedef struct _jc_soot_toolkits_scalar_SimpleLocalUses$sub_nonrefs	_jc_soot_toolkits_scalar_SimpleLocalUses$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_SimpleLocalUses$refs	_jc_soot_toolkits_scalar_SimpleLocalUses$refs;
typedef struct _jc_soot_toolkits_scalar_SimpleLocalUses$nonrefs	_jc_soot_toolkits_scalar_SimpleLocalUses$nonrefs;
typedef struct _jc_soot_toolkits_scalar_SimpleLocalUses$object	_jc_soot_toolkits_scalar_SimpleLocalUses$object;

typedef const struct _jc_soot_toolkits_scalar_SimpleLocalUses$vmethods	_jc_soot_toolkits_scalar_SimpleLocalUses$vmethods;
typedef const struct _jc_soot_toolkits_scalar_SimpleLocalUses$vtable	_jc_soot_toolkits_scalar_SimpleLocalUses$vtable;
typedef const struct _jc_soot_toolkits_scalar_SimpleLocalUses$vtype	_jc_soot_toolkits_scalar_SimpleLocalUses$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_SimpleLocalUses$method$_init$f9b52af7f539e9ce(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLocalUses$object *, struct _jc_soot_Body$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_toolkits_scalar_SimpleLocalUses$method$_init$b799bdb7699f2961(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLocalUses$object *, struct _jc_soot_toolkits_graph_UnitGraph$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_soot_toolkits_scalar_SimpleLocalUses$method$getUsesOf$de01c1d1f6666f7b(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLocalUses$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_scalar_SimpleLocalUses$method_info$getUsesOf$de01c1d1f6666f7b;

// Virtual methods structure
struct _jc_soot_toolkits_scalar_SimpleLocalUses$vmethods {
	struct _jc_object	*(*getUsesOf$de01c1d1f6666f7b)(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLocalUses$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_toolkits_scalar_SimpleLocalUses$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_SimpleLocalUses$vmethods	soot_toolkits_scalar_SimpleLocalUses;
};

// Vtype
struct _jc_soot_toolkits_scalar_SimpleLocalUses$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_SimpleLocalUses$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_SimpleLocalUses$sub_refs {
	struct _jc_object	*unitToUses;
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_SimpleLocalUses$refs {
    _jc_soot_toolkits_scalar_SimpleLocalUses$sub_refs	soot_toolkits_scalar_SimpleLocalUses;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_SimpleLocalUses$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_SimpleLocalUses$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_SimpleLocalUses$sub_nonrefs	soot_toolkits_scalar_SimpleLocalUses;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_SimpleLocalUses$object {
	_jc_soot_toolkits_scalar_SimpleLocalUses$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_SimpleLocalUses$vtype	*vtype;
	_jc_soot_toolkits_scalar_SimpleLocalUses$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_SimpleLocalUses$vtype _jc_soot_toolkits_scalar_SimpleLocalUses$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_SimpleLocalUses, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_SimpleLocalUses$class_object;

#endif	/* _JC_soot_toolkits_scalar_SimpleLocalUses_H_ */
